<?php
/**
 * Plugin plxMySubCategories
 * Gestion des sous-catégories
 *
 * @author	Stephane F
 **/
class plxMySubCategories extends plxPlugin {

	public $aCats = array();

	/**
	 * Constructeur de la classe
	 *
	 * @param	default_lang	langue par défaut
	 * @return	stdio
	 * @author	Stephane F
	 **/
	public function __construct($default_lang) {
		parent::__construct($default_lang);

		# droits pour accèder à la page config.php du plugin
		$this->setConfigProfil(PROFIL_ADMIN);

		# core/lib/class.plx.motor.php
		$this->addHook('plxMotorGetCategories', 'plxMotorGetCategories');
		# core/lib/class.plx.admin.php
		$this->addHook('plxAdminEditArticle', 'plxAdminEditArticle');
		$this->addHook('plxAdminEditCategoriesNew', 'plxAdminEditCategoriesNew');
		$this->addHook('plxAdminEditCategoriesUpdate', 'plxAdminEditCategoriesUpdate');
		$this->addHook('plxAdminEditCategoriesXml', 'plxAdminEditCategoriesXml');
		$this->addHook('plxAdminEditCategorie', 'plxAdminEditCategorie');
		# core/lib/class.plx.show.php
		$this->addHook('plxShowLastCatList', 'plxShowLastCatList');
		# core/admin/categorie.php
		$this->addHook('AdminCategory', 'AdminCategory');
		# core/admin/categories.php
		$this->addHook('AdminCategoriesTop', 'AdminCategoriesTop');
		$this->addHook('AdminCategoriesFoot', 'AdminCategoriesFoot');
		# core/admin/top.php et core/admin/articles.php
		$this->addHook('AdminTopBottom', 'AdminTopBottom');
		$this->addHook('AdminArticleSidebar', 'AdminArticleSidebar');

	}

	/*********************************************/
	/* méthodes pour le fonctionnement du plugin */
	/*********************************************/

	/**
	 * Méthode qui trie l'arborescence des sous-catégories
	 *
	 * @author	Stephane F
	 **/
	protected function sortCategories() {
		$plx = defined('PLX_ADMIN') ? plxAdmin::getInstance() : plxMotor::getInstance();
		$array = array();
		foreach($this->aCats as $numcat => $cat) {
			$array[$numcat] = $plx->aCats[$numcat];
			$array[$numcat]['level'] = $cat['level'];
		}
		$plx->aCats = $array;
	}

	/**
	 * Méthode récursive pour créer l'arborescences des categories/sous-catégories coté administration
	 *
	 * @param	idparent	id de la catégorie à explorer pour chercher les sous-catégories
	 * @param	level		niveau de la catégorie dans l'arborescence (0=racine)
	 * @author	Stephane F
	 **/
	protected function getCategories($idparent=0, $level=0) {
		$plx = defined('PLX_ADMIN') ? plxAdmin::getInstance() : plxMotor::getInstance();
		foreach($plx->aCats as $numcat => $cat) {
			if($idparent==$cat["parent"]) {
				$this->aCats[$numcat]['selected'] = ((isset($_GET['p']) AND $numcat==$_GET['p']) ? ' selected="selected' : '');
				$this->aCats[$numcat]['level'] = $level;
				$this->aCats[$numcat]['name'] = $cat['name'];
				$this->getCategories(intval($numcat), $level+1);
			}
		}

	}

	/************************************/
	/* core/admin/article.php (sidebar) */
	/************************************/

	public function AdminTopBottom() {
		echo "<?php ob_start(); ?>";
	}

	public function AdminArticleSidebar() {
		# récupération des catégories/sous-categories
		$this->getCategories();
		# tri  des catégories/sous-categories
		$this->sortCategories();
		# affichage avec indentation des sous-catégories
		echo '<?php
			$io = ob_get_clean();
			foreach($plxAdmin->aCats as $numcat => $cat) {
				$io = str_replace(
					"<input type=\"checkbox\" id=\"cat_".$numcat."\"",
					str_repeat("&nbsp;", $cat["level"]*5)."<input type=\"checkbox\" id=\"cat_".$numcat."\"",
					$io
				);
			}
			echo $io;

		?>';
	}

	/******************************/
	/* core/admin/categories.php  */
	/******************************/

	public function AdminCategoriesTop() {
		echo "<?php ob_start(); ?>";
	}

	public function AdminCategoriesFoot() {
		# récupération des catégories/sous-categories
		$this->getCategories();
		# tri  des catégories/sous-categories
		$this->sortCategories();
		# affichage avec indentation des sous-catégories
		echo '<?php
			$io = ob_get_clean();
			foreach($plxAdmin->aCats as $numcat => $cat) {
				$io = str_replace(
					"<td><input id=\"id_".$numcat."_name\"",
					"<td>".str_repeat("&nbsp;", $cat["level"]*5)."<input id=\"id_".$numcat."_name\"",
					$io
				);
			}
			echo $io;

		?>';
	}

	/********************************/
	/* core/lib/class.plx.show.php  */
	/********************************/

	/**
	 * Méthode chargée de l'affichage des catégories et sous-catégories
	 * en remplacement de la fonction plxShow::lastCatList()
	 *
	 * @return	stdio
	 * @author	Stephane F
	 **/
	public function plxShowLastCatList() {
		# récupération des catégories/sous-categories
		$this->getCategories();
		# tri  des catégories/sous-categories
		$this->sortCategories();
		#print_r($this->plxMotor->aCats);
		# affichage avec indentation des sous-catégories
		echo '<?php
		# Si on a la variable extra, on affiche un lien vers la page d"accueil (avec $extra comme nom)
		if($extra != "") {
			$name = str_replace("#cat_id","cat-home",$format);
			$name = str_replace("#cat_url",$this->plxMotor->urlRewrite(),$name);
			$name = str_replace("#cat_name",plxUtils::strCheck($extra),$name);
			$name = str_replace("#cat_status",($this->catId()=="home"?"active":"noactive"), $name);
			$name = str_replace("#art_nb","",$name);
			echo $name;
		}

		# On verifie qu"il y a des categories
		#print_r($this->plxMotor->aCats);
		if($this->plxMotor->aCats) {
			foreach($this->plxMotor->aCats as $k=>$v) {
				$in = (empty($include) OR preg_match("/(".$include.")/", $k) OR preg_match("/(".$include.")/", str_pad($v["parent"],3,"0",STR_PAD_LEFT)));
				$ex = (!empty($exclude) AND preg_match("/(".$exclude.")/", $k) AND preg_match("/(".$include.")/", str_pad($v["parent"],3,"0",STR_PAD_LEFT)));
				if($in AND !$ex) {
					if(($v["articles"]>0 OR $this->plxMotor->aConf["display_empty_cat"]) AND ($v["menu"]=="oui") AND $v["active"]) { # On a des articles
						# On modifie nos motifs
						$name = str_replace("#cat_id","cat-".intval($k),$format);
						$name = str_replace("#cat_url",$this->plxMotor->urlRewrite("?categorie".intval($k)."/".$v["url"]),$name);
						$name = str_replace("#cat_name",plxUtils::strCheck($v["name"]),$name);
						$name = str_replace("#cat_status",($this->catId()==intval($k)?"active":"noactive"), $name);
						$name = str_replace("#art_nb",$v["articles"],$name);
						# indentation de la catégorie en fonction de son niveau
						$name = str_replace("<a ", str_repeat("&nbsp;", ($v["level"]*5))."<a ", $name);
						$name = str_replace("<li", "<li class=\"cat-level-".$v["level"]."\"", $name);
						echo $name;
					}
				}
			} # Fin du while
		}
		# pour ne pas éxecuter la suite du code après appel du hook plxShowLastCatList
		return true;
		?>';
	}

	/*****************************/
	/* core/admin/categorie.php  */
	/*****************************/

	/**
	 * Méthode qui affiche un déroulant pour sélectionner la catégorie parent
	 *
	 * @return	stdio
	 * @author	Stephane F
	 **/
	public function AdminCategory() {
		# récupération des sous-catégories
		$this->getCategories();
		# affichage du déroulant
		echo '<p><label for="id_homepage">'.$this->getLang('L_CAT_PARENT').'&nbsp;:</label></p>';
		echo '<select name="parent">';
		echo '<option value="0">racine</option>';
		foreach($this->aCats as $numcat => $cat) {
			echo '<option'.$cat['selected'].' value="'.intval($numcat).'">'.str_repeat("&nbsp;", $cat['level']*5).plxUtils::strCheck($cat['name']).'</option>';
		}
		echo '</select>';
	}

	/*********************************/
	/* core/lib/class.plx.motor.php  */
	/*********************************/

	public function plxMotorGetCategories() {
		echo '<?php
			$parent = plxUtils::getValue($iTags["parent"][$i]);
			$this->aCats[$number]["parent"]=plxUtils::getValue($values[$parent]["value"],0);
		?>';
	}

	/*********************************/
	/* core/lib/class.plx.admin.php  */
	/*********************************/

	/**
	 * Méthode pour ajouter automatique les articles à la catégorie parent
	 *
	 * @return	stdio
	 * @author	Stephane F
	 **/
	public function plxAdminEditArticle() {
		if($this->getParam('addtoparent')) {
			echo '<?php
				foreach($content["catId"] as $cat) {
					$parent = str_pad($this->aCats[$cat]["parent"],3,"0",STR_PAD_LEFT);
					if(!in_array($parent,$content["catId"]) AND $parent!="000") {
						array_push($content["catId"], $parent);
					}
				}
			?>';
		}
	}

	//-----

	public function plxAdminEditCategorie() {
		echo '<?php $this->aCats[$content["id"]]["parent"] = $content["parent"]; ?>';
	}

	public function plxAdminEditCategoriesNew() {
		echo '<?php $this->aCats[$cat_id]["parent"] = 0; ?>';
	}

	public function plxAdminEditCategoriesUpdate() {
		echo '<?php $this->aCats[$cat_id]["parent"] = (isset($this->aCats[$cat_id]["parent"])?$this->aCats[$cat_id]["parent"]:"0"); ?>';
	}

	public function plxAdminEditCategoriesXml() {
		echo '<?php $xml .= "<parent>".intval($cat["parent"])."</parent>"; ?>';
	}

}
?>